@@ -27,13 +27,14 @@ import sys
 from argparse import ArgumentParser, Namespace, _SubParsersAction
 from difflib import get_close_matches
 from functools import cached_property
+from random import choice
 from typing import Any, Callable
 
 from prompt_toolkit import PromptSession
 from prompt_toolkit.formatted_text import StyleAndTextTuples
 from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.patch_stdout import patch_stdout
-from prompt_toolkit.validation import ValidationError, Validator
+from prompt_toolkit.validation import ValidationError
 from rich import box
 from rich.console import Console
 from rich.markdown import Markdown
@@ -66,41 +67,10 @@ from falyx.retry import RetryPolicy
 from falyx.signals import BackSignal, CancelSignal, HelpSignal, QuitSignal
 from falyx.themes import OneColors
 from falyx.utils import CaseInsensitiveDict, _noop, chunks, ensure_async
+from falyx.validators import CommandValidator
 from falyx.version import __version__
 
 
-class CommandValidator(Validator):
-    """Validator to check if the input is a valid command."""
-
-    def __init__(self, falyx: Falyx, error_message: str) -> None:
-        super().__init__()
-        self.falyx = falyx
-        self.error_message = error_message
-
-    def validate(self, document) -> None:
-        if not document.text:
-            raise ValidationError(
-                message=self.error_message,
-                cursor_position=len(document.text),
-            )
-
-    async def validate_async(self, document) -> None:
-        text = document.text
-        if not text:
-            raise ValidationError(
-                message=self.error_message,
-                cursor_position=len(text),
-            )
-        is_preview, choice, _, __ = await self.falyx.get_command(text, from_validate=True)
-        if is_preview:
-            return None
-        if not choice:
-            raise ValidationError(
-                message=self.error_message,
-                cursor_position=len(text),
-            )
-
-
 class Falyx:
     """
     Main menu controller for Falyx CLI applications.
@@ -156,6 +126,7 @@ class Falyx:
         title: str | Markdown = "Menu",
         *,
         program: str | None = "falyx",
+        program_style: str = OneColors.WHITE,
         usage: str | None = None,
         description: str | None = "Falyx CLI - Run structured async command workflows.",
         epilog: str | None = None,
@@ -176,6 +147,7 @@ class Falyx:
         render_menu: Callable[[Falyx], None] | None = None,
         custom_table: Callable[[Falyx], Table] | Table | None = None,
         hide_menu_table: bool = False,
+        show_placeholder_menu: bool = False,
     ) -> None:
         """Initializes the Falyx object."""
         self.title: str | Markdown = title
@@ -188,13 +160,6 @@ class Falyx:
         self.prompt: str | StyleAndTextTuples = rich_text_to_prompt_text(prompt)
         self.columns: int = columns
         self.commands: dict[str, Command] = CaseInsensitiveDict()
-        self.exit_command: Command = self._get_exit_command()
-        self.history_command: Command | None = (
-            self._get_history_command() if include_history_command else None
-        )
-        self.help_command: Command | None = (
-            self._get_help_command() if include_help_command else None
-        )
         self.console: Console = console
         self.welcome_message: str | Markdown | dict[str, Any] = welcome_message
         self.exit_message: str | Markdown | dict[str, Any] = exit_message
@@ -208,9 +173,25 @@ class Falyx:
         self.render_menu: Callable[[Falyx], None] | None = render_menu
         self.custom_table: Callable[[Falyx], Table] | Table | None = custom_table
         self._hide_menu_table: bool = hide_menu_table
+        self.show_placeholder_menu: bool = show_placeholder_menu
         self.validate_options(cli_args, options)
         self._prompt_session: PromptSession | None = None
         self.options.set("mode", FalyxMode.MENU)
+        self.exit_command: Command = self._get_exit_command()
+        self.history_command: Command | None = (
+            self._get_history_command() if include_history_command else None
+        )
+        self.help_command: Command | None = (
+            self._get_help_command() if include_help_command else None
+        )
+
+    @property
+    def is_cli_mode(self) -> bool:
+        return self.options.get("mode") in {
+            FalyxMode.RUN,
+            FalyxMode.PREVIEW,
+            FalyxMode.RUN_ALL,
+        }
 
     def validate_options(
         self,
@@ -291,6 +272,8 @@ class Falyx:
             style=OneColors.DARK_RED,
             simple_help_signature=True,
             ignore_in_history=True,
+            options_manager=self.options,
+            program=self.program,
         )
 
     def _get_history_command(self) -> Command:
@@ -300,6 +283,7 @@ class Falyx:
             command_description="History",
             command_style=OneColors.DARK_YELLOW,
             aliases=["HISTORY"],
+            program=self.program,
         )
         parser.add_argument(
             "-n",
@@ -343,17 +327,46 @@ class Falyx:
             arg_parser=parser,
             help_text="View the execution history of commands.",
             ignore_in_history=True,
+            options_manager=self.options,
+            program=self.program,
         )
 
+    def get_tip(self) -> str:
+        program = f"{self.program} run " if self.is_cli_mode else ""
+        tips = [
+            f"Tip: Use '{program}?[KEY]' to preview a command.",
+            f"Tip: Use '{program}?' alone to list all commands at any time.",
+            "Tip: Every command supports aliases—try abbreviating the name!",
+            f"Tip: Use '{program}H' to reopen this help menu anytime.",
+            f"Tip: '{program}[KEY] --help' prints a detailed help message.",
+            "Tip: Mix CLI and menu mode—commands run the same way in both.",
+            f"Tip: Use '{self.program} --never-prompt' to disable all prompts for the [bold italic]entire menu session[/].",
+            f"Tip: Use '{self.program} --verbose' to enable debug logging for a menu session.",
+            f"Tip: '{self.program} --debug-hooks' will trace every before/after hook in action.",
+            f"Tip: Run commands directly from the CLI: '{self.program} run [KEY] [OPTIONS]'.",
+        ]
+        if self.is_cli_mode:
+            tips.extend(
+                [
+                    f"Tip: Use '{self.program} --never-prompt run [KEY]' to disable all prompts for [bold italic]just this command[/].",
+                    f"Tip: Use '{self.program} run --skip-confirm [KEY]' to skip confirmations.",
+                    f"Tip: Use '{self.program} run --summary [KEY]' to print a post-run summary.",
+                    f"Tip: Use '{self.program} --verbose run [KEY]' to enable debug logging for any run.",
+                    "Tip: Use '--skip-confirm' for automation scripts where no prompts are wanted.",
+                ]
+            )
+        else:
+            tips.extend(
+                [
+                    "Tip: '[CTRL+KEY]' toggles are available in menu mode for quick switches.",
+                    "Tip: '[Y]' opens the command history viewer.",
+                    "Tip: Use '[X]' in menu mode to exit.",
+                ]
+            )
+        return choice(tips)
+
     async def _show_help(self, tag: str = "") -> None:
         if tag:
-            table = Table(
-                title=tag.upper(),
-                title_justify="left",
-                show_header=False,
-                box=box.SIMPLE,
-                show_footer=False,
-            )
             tag_lower = tag.lower()
             commands = [
                 command
@@ -361,27 +374,29 @@ class Falyx:
                 if any(tag_lower == tag.lower() for tag in command.tags)
             ]
             for command in commands:
-                table.add_row(command.help_signature)
-            self.console.print(table)
+                usage, description = command.help_signature
+                self.console.print(usage)
+                if description:
+                    self.console.print(description)
             return
-        else:
-            table = Table(
-                title="Help",
-                title_justify="left",
-                title_style=OneColors.LIGHT_YELLOW_b,
-                show_header=False,
-                show_footer=False,
-                box=box.SIMPLE,
-            )
-            for command in self.commands.values():
-                table.add_row(command.help_signature)
+
+        for command in self.commands.values():
+            usage, description = command.help_signature
+            self.console.print(usage)
+            if description:
+                self.console.print(description)
         if self.help_command:
-            table.add_row(self.help_command.help_signature)
-        if self.history_command:
-            table.add_row(self.history_command.help_signature)
-        table.add_row(self.exit_command.help_signature)
-        table.add_row(f"Tip: '[{OneColors.LIGHT_YELLOW}]?[KEY][/]' to preview a command ")
-        self.console.print(table)
+            usage, description = self.help_command.help_signature
+            self.console.print(usage)
+            self.console.print(description)
+        if not self.is_cli_mode:
+            if self.history_command:
+                usage, description = self.history_command.help_signature
+                self.console.print(usage)
+                self.console.print(description)
+            usage, _ = self.exit_command.help_signature
+            self.console.print(usage)
+        self.console.print(self.get_tip())
 
     def _get_help_command(self) -> Command:
         """Returns the help command for the menu."""
@@ -390,6 +405,7 @@ class Falyx:
             command_description="Help",
             command_style=OneColors.LIGHT_YELLOW,
             aliases=["?", "HELP", "LIST"],
+            program=self.program,
         )
         parser.add_argument(
             "-t",
@@ -407,6 +423,8 @@ class Falyx:
             style=OneColors.LIGHT_YELLOW,
             arg_parser=parser,
             ignore_in_history=True,
+            options_manager=self.options,
+            program=self.program,
         )
 
     def _get_completer(self) -> FalyxCompleter:
@@ -492,6 +510,7 @@ class Falyx:
     def prompt_session(self) -> PromptSession:
         """Returns the prompt session for the menu."""
         if self._prompt_session is None:
+            placeholder = self.build_placeholder_menu()
             self._prompt_session = PromptSession(
                 message=self.prompt,
                 multiline=False,
@@ -502,6 +521,7 @@ class Falyx:
                 validate_while_typing=True,
                 interrupt_exception=QuitSignal,
                 eof_exception=QuitSignal,
+                placeholder=placeholder if self.show_placeholder_menu else None,
             )
         return self._prompt_session
 
@@ -576,6 +596,8 @@ class Falyx:
             confirm=confirm,
             confirm_message=confirm_message,
             ignore_in_history=True,
+            options_manager=self.options,
+            program=self.program,
         )
 
     def add_submenu(
@@ -724,16 +746,16 @@ class Falyx:
         if self.help_command:
             bottom_row.append(
                 f"[{self.help_command.key}] [{self.help_command.style}]"
-                f"{self.help_command.description}"
+                f"{self.help_command.description}[/]"
             )
         if self.history_command:
             bottom_row.append(
                 f"[{self.history_command.key}] [{self.history_command.style}]"
-                f"{self.history_command.description}"
+                f"{self.history_command.description}[/]"
             )
         bottom_row.append(
             f"[{self.exit_command.key}] [{self.exit_command.style}]"
-            f"{self.exit_command.description}"
+            f"{self.exit_command.description}[/]"
         )
         return bottom_row
 
@@ -754,6 +776,22 @@ class Falyx:
             table.add_row(*row)
         return table
 
+    def build_placeholder_menu(self) -> StyleAndTextTuples:
+        """
+        Builds a menu placeholder for show_placeholder_menu.
+        """
+        visible_commands = [item for item in self.commands.items() if not item[1].hidden]
+        if not visible_commands:
+            return [("", "")]
+
+        placeholder: list[str] = []
+        for key, command in visible_commands:
+            placeholder.append(f"[{key}] [{command.style}]{command.description}[/]")
+        for command_str in self.get_bottom_row():
+            placeholder.append(command_str)
+
+        return rich_text_to_prompt_text(" ".join(placeholder))
+
     @property
     def table(self) -> Table:
         """Creates or returns a custom table to display the menu commands."""
