@@ -46,9 +46,8 @@ and complex multi-level conflict handling. Instead, it favors:
 """
 from __future__ import annotations
 
-from collections import defaultdict
+from collections import Counter, defaultdict
 from copy import deepcopy
-from dataclasses import dataclass
 from typing import Any, Iterable, Sequence
 
 from rich.console import Console
@@ -63,23 +62,11 @@ from falyx.mode import FalyxMode
 from falyx.options_manager import OptionsManager
 from falyx.parser.argument import Argument
 from falyx.parser.argument_action import ArgumentAction
-from falyx.parser.parser_types import false_none, true_none
+from falyx.parser.parser_types import ArgumentState, TLDRExample, false_none, true_none
 from falyx.parser.utils import coerce_value
 from falyx.signals import HelpSignal
 
 
-@dataclass
-class ArgumentState:
-    arg: Argument
-    consumed: bool = False
-
-
-@dataclass(frozen=True)
-class TLDRExample:
-    usage: str
-    description: str
-
-
 class CommandArgumentParser:
     """
     Custom argument parser for Falyx Commands.
@@ -101,6 +88,8 @@ class CommandArgumentParser:
     - Render Help using Rich library.
     """
 
+    RESERVED_DESTS = frozenset(("help", "tldr"))
+
     def __init__(
         self,
         command_key: str = "",
@@ -138,13 +127,13 @@ class CommandArgumentParser:
 
     def _add_help(self):
         """Add help argument to the parser."""
-        self.add_argument(
-            "-h",
-            "--help",
+        help = Argument(
+            flags=("--help", "-h"),
             action=ArgumentAction.HELP,
             help="Show this help message.",
             dest="help",
         )
+        self._register_argument(help)
 
     def add_tldr_examples(self, examples: list[tuple[str, str]]) -> None:
         """
@@ -153,22 +142,24 @@ class CommandArgumentParser:
         Args:
             examples (list[tuple[str, str]]): List of (usage, description) tuples.
         """
-        if not any(
+        if not all(
             isinstance(example, tuple) and len(example) == 2 for example in examples
         ):
             raise CommandArgumentError(
                 "TLDR examples must be a list of (usage, description) tuples"
             )
+
         for usage, description in examples:
             self._tldr_examples.append(TLDRExample(usage=usage, description=description))
 
         if "tldr" not in self._dest_set:
-            self.add_argument(
-                "--tldr",
+            tldr = Argument(
+                ("--tldr",),
                 action=ArgumentAction.TLDR,
                 help="Show quick usage examples and exit.",
                 dest="tldr",
             )
+            self._register_argument(tldr)
 
     def _is_positional(self, flags: tuple[str, ...]) -> bool:
         """Check if the flags are positional."""
@@ -479,7 +470,10 @@ class CommandArgumentParser:
         if argument.positional:
             self._positional[argument.dest] = argument
         else:
-            self._keyword_list.append(argument)
+            if argument.action == ArgumentAction.TLDR:
+                self._keyword_list.insert(1, argument)
+            else:
+                self._keyword_list.append(argument)
 
     def add_argument(
         self,
@@ -526,6 +520,10 @@ class CommandArgumentParser:
                 "Merging multiple arguments into the same dest (e.g. positional + flagged) "
                 "is not supported. Define a unique 'dest' for each argument."
             )
+        if dest in self.RESERVED_DESTS:
+            raise CommandArgumentError(
+                f"Destination '{dest}' is reserved and cannot be used."
+            )
         action = self._validate_action(action, positional)
         resolver = self._validate_resolver(action, resolver)
 
@@ -610,6 +608,25 @@ class CommandArgumentParser:
             )
         return defs
 
+    def _check_if_in_choices(
+        self,
+        spec: Argument,
+        result: dict[str, Any],
+        arg_states: dict[str, ArgumentState],
+    ) -> None:
+        if not spec.choices:
+            return None
+        value_check = result.get(spec.dest)
+        if isinstance(value_check, list):
+            for value in value_check:
+                if value in spec.choices:
+                    return None
+        if value_check in spec.choices:
+            return None
+        raise CommandArgumentError(
+            f"Invalid value for '{spec.dest}': must be one of {{{', '.join(spec.choices)}}}"
+        )
+
     def _raise_remaining_args_error(
         self, token: str, arg_states: dict[str, ArgumentState]
     ) -> None:
@@ -738,6 +755,7 @@ class CommandArgumentParser:
                         raise CommandArgumentError(
                             f"[{spec.dest}] Action failed: {error}"
                         ) from error
+                self._check_if_in_choices(spec, result, arg_states)
                 arg_states[spec.dest].consumed = True
             elif not typed and spec.default:
                 result[spec.dest] = spec.default
@@ -751,9 +769,11 @@ class CommandArgumentParser:
                 assert result.get(spec.dest) is not None, "dest should not be None"
                 result[spec.dest].extend(typed)
             elif spec.nargs in (None, 1, "?"):
-                arg_states[spec.dest].consumed = True
                 result[spec.dest] = typed[0] if len(typed) == 1 else typed
+                self._check_if_in_choices(spec, result, arg_states)
+                arg_states[spec.dest].consumed = True
             else:
+                self._check_if_in_choices(spec, result, arg_states)
                 arg_states[spec.dest].consumed = True
                 result[spec.dest] = typed
 
@@ -832,6 +852,7 @@ class CommandArgumentParser:
                         raise CommandArgumentError(
                             f"[{spec.dest}] Action failed: {error}"
                         ) from error
+                self._check_if_in_choices(spec, result, arg_states)
                 arg_states[spec.dest].consumed = True
                 consumed_indices.update(range(i, new_i))
                 i = new_i
@@ -917,6 +938,7 @@ class CommandArgumentParser:
                     )
                 else:
                     result[spec.dest] = typed_values
+                self._check_if_in_choices(spec, result, arg_states)
                 arg_states[spec.dest].consumed = True
                 consumed_indices.update(range(i, new_i))
                 i = new_i
@@ -1007,10 +1029,12 @@ class CommandArgumentParser:
                     and from_validate
                 ):
                     if not args:
+                        arg_states[spec.dest].consumed = False
                         raise CommandArgumentError(
                             f"Missing required argument '{spec.dest}': {spec.get_choice_text()}{help_text}"
                         )
                     continue  # Lazy resolvers are not validated here
+                arg_states[spec.dest].consumed = False
                 raise CommandArgumentError(
                     f"Missing required argument '{spec.dest}': {spec.get_choice_text()}{help_text}"
                 )
@@ -1033,20 +1057,24 @@ class CommandArgumentParser:
                 if spec.action == ArgumentAction.APPEND:
                     for group in result[spec.dest]:
                         if len(group) % spec.nargs != 0:
+                            arg_states[spec.dest].consumed = False
                             raise CommandArgumentError(
                                 f"Invalid number of values for '{spec.dest}': expected a multiple of {spec.nargs}"
                             )
                 elif spec.action == ArgumentAction.EXTEND:
                     if len(result[spec.dest]) % spec.nargs != 0:
+                        arg_states[spec.dest].consumed = False
                         raise CommandArgumentError(
                             f"Invalid number of values for '{spec.dest}': expected a multiple of {spec.nargs}"
                         )
                 elif len(result[spec.dest]) != spec.nargs:
+                    arg_states[spec.dest].consumed = False
                     raise CommandArgumentError(
                         f"Invalid number of values for '{spec.dest}': expected {spec.nargs}, got {len(result[spec.dest])}"
                     )
 
         result.pop("help", None)
+        result.pop("tldr", None)
         return result
 
     async def parse_args_split(
@@ -1064,7 +1092,7 @@ class CommandArgumentParser:
         args_list = []
         kwargs_dict = {}
         for arg in self._arguments:
-            if arg.dest == "help":
+            if arg.dest in ("help", "tldr"):
                 continue
             if arg.positional:
                 args_list.append(parsed[arg.dest])
@@ -1094,6 +1122,7 @@ class CommandArgumentParser:
             if not state.consumed:
                 next_non_consumed_positional = state.arg
                 break
+
         if next_non_consumed_positional:
             if next_non_consumed_positional.choices:
                 return sorted(
@@ -1112,13 +1141,23 @@ class CommandArgumentParser:
             flag for flag, arg in self._keyword.items() if arg.dest not in consumed_dests
         ]
 
+        last_keyword_state_in_args = None
+        for last_arg in reversed(args):
+            if last_arg in self._keyword:
+                last_keyword_state_in_args = self._last_keyword_states.get(
+                    self._keyword[last_arg].dest
+                )
+                break
+
         last = args[-1]
         next_to_last = args[-2] if len(args) > 1 else ""
         suggestions: list[str] = []
 
         # Case 2: Mid-flag (e.g., "--ver")
         if last.startswith("-") and last not in self._keyword:
-            if (
+            if last_keyword_state_in_args and not last_keyword_state_in_args.consumed:
+                pass
+            elif (
                 len(args) > 1
                 and next_to_last in self._keyword
                 and next_to_last in remaining_flags
@@ -1139,14 +1178,31 @@ class CommandArgumentParser:
         # Case 3: Flag that expects a value (e.g., ["--tag"])
         elif last in self._keyword:
             arg = self._keyword[last]
-            if arg.choices:
+            if (
+                self._last_keyword_states.get(last.strip("-"))
+                and self._last_keyword_states[last.strip("-")].consumed
+            ):
+                pass
+            elif arg.choices:
                 suggestions.extend(arg.choices)
             elif arg.suggestions:
                 suggestions.extend(arg.suggestions)
         # Case 4: Last flag with choices mid-choice (e.g., ["--tag", "v"])
         elif next_to_last in self._keyword:
             arg = self._keyword[next_to_last]
-            if arg.choices and last not in arg.choices:
+            if (
+                self._last_keyword_states.get(next_to_last.strip("-"))
+                and self._last_keyword_states[next_to_last.strip("-")].consumed
+                and last_keyword_state_in_args
+                and Counter(args)[next_to_last]
+                > (
+                    last_keyword_state_in_args.arg.nargs
+                    if isinstance(last_keyword_state_in_args.arg.nargs, int)
+                    else 1
+                )
+            ):
+                pass
+            elif arg.choices and last not in arg.choices and not cursor_at_end_of_token:
                 suggestions.extend(arg.choices)
             elif (
                 arg.suggestions
@@ -1156,8 +1212,12 @@ class CommandArgumentParser:
                 and not cursor_at_end_of_token
             ):
                 suggestions.extend(arg.suggestions)
+            elif last_keyword_state_in_args and not last_keyword_state_in_args.consumed:
+                pass
             else:
                 suggestions.extend(remaining_flags)
+        elif last_keyword_state_in_args and not last_keyword_state_in_args.consumed:
+            pass
         # Case 5: Suggest all remaining flags
         else:
             suggestions.extend(remaining_flags)
@@ -1302,8 +1362,11 @@ class CommandArgumentParser:
         program = self.program or "falyx"
         command = self.aliases[0] if self.aliases else self.command_key
         if is_cli_mode:
-            command = f"{program} run {command}"
-        command = f"[{self.command_style}]{command}[/{self.command_style}]"
+            command = (
+                f"[{self.command_style}]{program} run {command}[/{self.command_style}]"
+            )
+        else:
+            command = f"[{self.command_style}]{command}[/{self.command_style}]"
 
         usage = self.get_usage()
         self.console.print(f"[bold]usage:[/] {usage}\n")
@@ -1315,8 +1378,9 @@ class CommandArgumentParser:
         for example in self._tldr_examples:
             usage = f"{command} {example.usage.strip()}"
             description = example.description.strip()
-            block = f"[bold]{usage}[/bold]\n{description}"
+            block = f"[bold]{usage}[/bold]"
             self.console.print(Padding(Panel(block, expand=False), (0, 2)))
+            self.console.print(f"    {description}", style="dim")
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, CommandArgumentParser):
